import type { FC, MouseEvent } from "react";
import React, { useCallback, useMemo } from "react";

import { useWalletModal } from "../hooks";
import type { ButtonProps } from "./Button";
import { Button } from "./Button";
import {
  handleRedirectIfDemonNotInstalled,
  isDemonWalletDetected,
} from "../helpers";

export const WalletModalButton: FC<ButtonProps> = ({
  onClick,
  ...props
}) => {
  const { visible, setVisible, trans } = useWalletModal();


  const handleClick = useCallback(
    (event: MouseEvent<HTMLButtonElement>) => {
      if (onClick) onClick(event);
      if (!event.defaultPrevented) {
        if (isDemonWalletDetected()) {
          setVisible(!visible);
        } else {
          handleRedirectIfDemonNotInstalled();
        }
      }
    },
    [onClick, setVisible, visible]
  );

  return (
    <Button
      className="wallet-adapter-button-trigger"
      onClick={handleClick}
      {...props}
    >
      {trans.connect_wallet}
    </Button>
  );
};
